---
name: "\U0001F41B Bug report"
about: Create a report to help us improve
labels: bug, new
---

##### ISSUE TYPE

- Bug Report

##### SUMMARY

<!-- Briefly describe the problem. -->

##### ANSIBLE-NAVIGATOR VERSION

<!--- Paste, BELOW THIS COMMENT, verbatim output from "ansible-navigator --version" between quotes below -->

```

```

##### CONFIGURATION

<!--- Paste verbatim output from `ansible-navigator.yaml` file or
      any other custom setting file defined by `ANSIBLE_NAVIGATOR_CONFIG`
      environment variable below (if present).-->

##### LOG FILE

<!--- Paste relevant logs from the ansible-navigator
      log file preferably after setting the log-level to `debug`,
      under the prompt line.
      **HINT:** You can paste https://gist.github.com links for larger files..-->

##### STEPS TO REPRODUCE

<!-- Please describe exactly how to reproduce the problem. -->

##### EXPECTED RESULTS

<!-- What did you expect to happen when running the steps above? -->

##### ACTUAL RESULTS

<!-- What actually happened? -->

##### ADDITIONAL INFORMATION

<!-- Include any links screenshots or other
additional information like execution-envirnment details
if enabled. You can use command
"ansible-navigator images <name-of-container-image>"
to introspect execution environment -->
